@@ -4,7 +4,7 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.18_15';
+  our $VERSION = '0.18_16';
 
   use Zydeco
     authority => 'cpan:SMONFF',
@@ -587,7 +587,7 @@ The fame he fame will go lower
 
 =item no parameter
 
-In that case the value defined by C<$self->config->{ FAME }->{ DEFAULT_BUMP }>
+In that case the value defined by C<< $self->config->{ FAME }->{ DEFAULT_BUMP } >>
 will be used to increase the reputation.
 
 =back
